Struct piston_meta::meta_rules::UntilAnyOrWhitespace
[−]
[src]
pub struct UntilAnyOrWhitespace {
pub any_characters: Arc<String>,
pub optional: bool,
pub property: Option<Arc<String>>,
pub debug_id: DebugId,
}Stores information about reading until whitespace or any of some character.
Fields
any_characters: Arc<String>
The characters to stop at.
optional: bool
Whether empty data is accepted or not.
property: Option<Arc<String>>
The property to store read text.
debug_id: DebugId
A debug id to track down the rule generating an error.
Methods
impl UntilAnyOrWhitespace[src]
fn parse(
&self,
tokens: &mut Vec<Range<MetaData>>,
state: &TokenizerState,
read_token: &ReadToken
) -> ParseResult<TokenizerState>
&self,
tokens: &mut Vec<Range<MetaData>>,
state: &TokenizerState,
read_token: &ReadToken
) -> ParseResult<TokenizerState>
Parses until whitespace or any specified characters.